@@ -61,8 +61,9 @@ var group__wt =
       [ "drop", "struct_w_t___s_e_s_s_i_o_n.html#adf785ef53c16d9dcc77e22cc04c87b70", null ],
       [ "join", "struct_w_t___s_e_s_s_i_o_n.html#ae0ab118df83d173c6a20eb1ea3f3fd84", null ],
       [ "log_flush", "struct_w_t___s_e_s_s_i_o_n.html#a1843292630960309129dcfe00e1a3817", null ],
-      [ "log_printf", "struct_w_t___s_e_s_s_i_o_n.html#a504625d0b35da78f738d08530a409be9", null ],
+      [ "log_printf", "struct_w_t___s_e_s_s_i_o_n.html#ac85541ca42d7596857d9f50e03c78eb5", null ],
       [ "open_cursor", "struct_w_t___s_e_s_s_i_o_n.html#afb5b4a69c2c5cafe411b2b04fdc1c75d", null ],
+      [ "prepare_transaction", "struct_w_t___s_e_s_s_i_o_n.html#a96b8a369610c8cbb08b8a7c504fd1008", null ],
       [ "rebalance", "struct_w_t___s_e_s_s_i_o_n.html#ab21ec3055cade4d2682f162783314984", null ],
       [ "reconfigure", "struct_w_t___s_e_s_s_i_o_n.html#a578f0fbd8a83339f1f9c00e135f006e6", null ],
       [ "rename", "struct_w_t___s_e_s_s_i_o_n.html#a1d24b02549009f78b7c6463da0247614", null ],
@@ -71,6 +72,7 @@ var group__wt =
       [ "salvage", "struct_w_t___s_e_s_s_i_o_n.html#ab3399430e474f7005bd5ea20e6ec7a8e", null ],
       [ "snapshot", "struct_w_t___s_e_s_s_i_o_n.html#ab15f6b5f81e6e98c9b6b41c451732873", null ],
       [ "strerror", "struct_w_t___s_e_s_s_i_o_n.html#abe03ccb716e097ed1bb4d42eb733c1f9", null ],
+      [ "timestamp_transaction", "struct_w_t___s_e_s_s_i_o_n.html#aa449082ce4de7ee86a773595c416a69f", null ],
       [ "transaction_pinned_range", "struct_w_t___s_e_s_s_i_o_n.html#a1d108fab498cfddbb09ee23e3321a88d", null ],
       [ "transaction_sync", "struct_w_t___s_e_s_s_i_o_n.html#a61c8c3ad80d8228172db66ca70bd90fd", null ],
       [ "truncate", "struct_w_t___s_e_s_s_i_o_n.html#ac2bad195e24710d52d730fe3a7c1756a", null ],
@@ -93,9 +95,12 @@ var group__wt =
       [ "get_home", "struct_w_t___c_o_n_n_e_c_t_i_o_n.html#a488fcba6b5abcdfca439d456564e8640", null ],
       [ "is_new", "struct_w_t___c_o_n_n_e_c_t_i_o_n.html#ae2bacefe9777b8ab32d8b22c292c4f39", null ],
       [ "load_extension", "struct_w_t___c_o_n_n_e_c_t_i_o_n.html#ab6a56facfd217e5ff687aa4c012e8d68", null ],
-      [ "open_session", "struct_w_t___c_o_n_n_e_c_t_i_o_n.html#afc75c44ff4497627c59d9b6aaa64c9d8", null ],
+      [ "open_session", "struct_w_t___c_o_n_n_e_c_t_i_o_n.html#adad5965cd4a60f65b5ac01f7ca6d1fc0", null ],
+      [ "query_timestamp", "struct_w_t___c_o_n_n_e_c_t_i_o_n.html#a607cf2781661d03ba50586133e02cc11", null ],
       [ "reconfigure", "struct_w_t___c_o_n_n_e_c_t_i_o_n.html#a579141678af06217b22869cbc604c6d4", null ],
-      [ "set_file_system", "struct_w_t___c_o_n_n_e_c_t_i_o_n.html#a7c9d5b40133a6ba1cbc4a6b1d8e1e86b", null ]
+      [ "rollback_to_stable", "struct_w_t___c_o_n_n_e_c_t_i_o_n.html#a93dbc74accb426582b3c5c2f69e04b28", null ],
+      [ "set_file_system", "struct_w_t___c_o_n_n_e_c_t_i_o_n.html#a7c9d5b40133a6ba1cbc4a6b1d8e1e86b", null ],
+      [ "set_timestamp", "struct_w_t___c_o_n_n_e_c_t_i_o_n.html#ad082439541b1b95d6aae6c15026fe512", null ]
     ] ],
     [ "WT_ASYNC_CALLBACK", "struct_w_t___a_s_y_n_c___c_a_l_l_b_a_c_k.html", [
       [ "notify", "struct_w_t___a_s_y_n_c___c_a_l_l_b_a_c_k.html#a8859d51cae96e48f79bbd8322ee347ea", null ]
@@ -106,16 +111,16 @@ var group__wt =
       [ "handle_message", "struct_w_t___e_v_e_n_t___h_a_n_d_l_e_r.html#af08d42a14b46863708b2d453e99cd9c1", null ],
       [ "handle_progress", "struct_w_t___e_v_e_n_t___h_a_n_d_l_e_r.html#ad45e36ca496da5f15bb87ba5bfdecc2b", null ]
     ] ],
-    [ "WT_CONFIG_ITEM", "group__wt.html#struct_w_t___c_o_n_f_i_g___i_t_e_m", [
-      [ "WT_CONFIG_ITEM_STRING", "group__wt.html#a215d5ce41e53aa467dd940bace3f25f0aaf3e84e05814a538b630d161edba9c2d", null ],
-      [ "WT_CONFIG_ITEM_BOOL", "group__wt.html#a215d5ce41e53aa467dd940bace3f25f0af17eadafa19dbf7e4679c9268289494d", null ],
-      [ "WT_CONFIG_ITEM_ID", "group__wt.html#a215d5ce41e53aa467dd940bace3f25f0ad4cc6c35b608ec98a207cfd1d3a13922", null ],
-      [ "WT_CONFIG_ITEM_NUM", "group__wt.html#a215d5ce41e53aa467dd940bace3f25f0a0d98189cee0438cd6c91bec663233085", null ],
-      [ "WT_CONFIG_ITEM_STRUCT", "group__wt.html#a215d5ce41e53aa467dd940bace3f25f0aa60d34a8a1fb1c7468cbd747a117fa8b", null ],
-      [ "len", "group__wt.html#adff0f6e5a3f781f0228015e8336f1a14", null ],
-      [ "str", "group__wt.html#aa0ce7d30a32600e16824966c638ee45f", null ],
-      [ "type", "group__wt.html#a02883d8649c8f9cf4047ada5f7db9245", null ],
-      [ "val", "group__wt.html#a4aefab7843f434e5a5cc18203e9fec5f", null ]
+    [ "WT_CONFIG_ITEM", "struct_w_t___c_o_n_f_i_g___i_t_e_m.html", [
+      [ "WT_CONFIG_ITEM_STRING", "struct_w_t___c_o_n_f_i_g___i_t_e_m.html#a215d5ce41e53aa467dd940bace3f25f0aaf3e84e05814a538b630d161edba9c2d", null ],
+      [ "WT_CONFIG_ITEM_BOOL", "struct_w_t___c_o_n_f_i_g___i_t_e_m.html#a215d5ce41e53aa467dd940bace3f25f0af17eadafa19dbf7e4679c9268289494d", null ],
+      [ "WT_CONFIG_ITEM_ID", "struct_w_t___c_o_n_f_i_g___i_t_e_m.html#a215d5ce41e53aa467dd940bace3f25f0ad4cc6c35b608ec98a207cfd1d3a13922", null ],
+      [ "WT_CONFIG_ITEM_NUM", "struct_w_t___c_o_n_f_i_g___i_t_e_m.html#a215d5ce41e53aa467dd940bace3f25f0a0d98189cee0438cd6c91bec663233085", null ],
+      [ "WT_CONFIG_ITEM_STRUCT", "struct_w_t___c_o_n_f_i_g___i_t_e_m.html#a215d5ce41e53aa467dd940bace3f25f0aa60d34a8a1fb1c7468cbd747a117fa8b", null ],
+      [ "len", "struct_w_t___c_o_n_f_i_g___i_t_e_m.html#adff0f6e5a3f781f0228015e8336f1a14", null ],
+      [ "str", "struct_w_t___c_o_n_f_i_g___i_t_e_m.html#aa0ce7d30a32600e16824966c638ee45f", null ],
+      [ "type", "struct_w_t___c_o_n_f_i_g___i_t_e_m.html#a02883d8649c8f9cf4047ada5f7db9245", null ],
+      [ "val", "struct_w_t___c_o_n_f_i_g___i_t_e_m.html#a4aefab7843f434e5a5cc18203e9fec5f", null ]
     ] ],
     [ "WT_CONFIG_PARSER", "struct_w_t___c_o_n_f_i_g___p_a_r_s_e_r.html", [
       [ "close", "struct_w_t___c_o_n_f_i_g___p_a_r_s_e_r.html#a44eea5e27a4da10006ab444ee7cf00f3", null ],
@@ -127,10 +132,14 @@ var group__wt =
     [ "WT_ERROR", "group__wt.html#gafdfe4d6ca06cb7337272f883f60c991e", null ],
     [ "WT_INTPACK32_MAXSIZE", "group__wt.html#ga56fdfd15cc3721bcb251cfc859a915ad", null ],
     [ "WT_INTPACK64_MAXSIZE", "group__wt.html#ga562d6f7fd9a3ffdb4089c1469b1609f8", null ],
+    [ "WT_LOGOP_CHECKPOINT_START", "group__wt.html#ga079e6a0b20affec5374bcc34e770ac0f", null ],
+    [ "WT_LOGOP_COL_MODIFY", "group__wt.html#ga69f6ee78c9d3e9d5105d255778113f99", null ],
     [ "WT_LOGOP_COL_PUT", "group__wt.html#ga60f5a86dcf273140cf03b3b0211b52b0", null ],
     [ "WT_LOGOP_COL_REMOVE", "group__wt.html#ga8a9c67c4247223506eb037e85239ae59", null ],
     [ "WT_LOGOP_COL_TRUNCATE", "group__wt.html#ga7b90b6193b0e42867704d629c6c81bc3", null ],
     [ "WT_LOGOP_INVALID", "group__wt.html#ga2f69defe9f4a1711da1377a079fe9754", null ],
+    [ "WT_LOGOP_PREV_LSN", "group__wt.html#ga3ef3af55614bbb5b1cd0e626c46dad24", null ],
+    [ "WT_LOGOP_ROW_MODIFY", "group__wt.html#ga9053af2348a51595e7ffff81492c1b5b", null ],
     [ "WT_LOGOP_ROW_PUT", "group__wt.html#ga696e6723bc1e3d4c3e5b5dde84fed73e", null ],
     [ "WT_LOGOP_ROW_REMOVE", "group__wt.html#ga3583383fc8ba9c297b3df83e216cdd01", null ],
     [ "WT_LOGOP_ROW_TRUNCATE", "group__wt.html#ga709b4bff9cc64662aca0b5e7ebcedf86", null ],
@@ -138,8 +147,10 @@ var group__wt =
     [ "WT_LOGREC_COMMIT", "group__wt.html#gafa49e810f6f760c2bcd2721ec2934991", null ],
     [ "WT_LOGREC_FILE_SYNC", "group__wt.html#gac87bc0790c3fa62c75fce67417178c8e", null ],
     [ "WT_LOGREC_MESSAGE", "group__wt.html#ga8cf04a003979e7852209079d4093d783", null ],
+    [ "WT_LOGREC_SYSTEM", "group__wt.html#ga65a82cc484f9e18f6e6319425af0f908", null ],
     [ "WT_NOTFOUND", "group__wt.html#ga3c9e1b494d95cf34404ab7a974af6bf8", null ],
     [ "WT_PANIC", "group__wt.html#gaf4fc8744eb8fe4f1c6e125d0f2361992", null ],
+    [ "WT_PREPARE_CONFLICT", "group__wt.html#ga62f73045c5d37d8daee4533dd720376e", null ],
     [ "WT_ROLLBACK", "group__wt.html#ga5ee3c6fcd074e11efd118f3e68e91db8", null ],
     [ "WT_RUN_RECOVERY", "group__wt.html#ga76bb44d946fbe56ddb93470ab95a1e78", null ],
     [ "WT_STAT_CONN_APPLICATION_CACHE_TIME", "group__wt.html#ga82db17f977dfe8bb1b1caf2b594a33b8", null ],
@@ -170,6 +181,7 @@ var group__wt =
     [ "WT_STAT_CONN_CACHE_BYTES_INTERNAL", "group__wt.html#gabf5032c8b498b0c6824cdb1f2497955e", null ],
     [ "WT_STAT_CONN_CACHE_BYTES_INUSE", "group__wt.html#ga5d9371b0feab441fda3d791cb51992c4", null ],
     [ "WT_STAT_CONN_CACHE_BYTES_LEAF", "group__wt.html#gae4459a1a24408a41ed06db998cfec3cc", null ],
+    [ "WT_STAT_CONN_CACHE_BYTES_LOOKASIDE", "group__wt.html#ga8c487ac18d440c9a29ad5536cd0ff25f", null ],
     [ "WT_STAT_CONN_CACHE_BYTES_MAX", "group__wt.html#ga1fcf0c7313ec964431509e60b4e57db8", null ],
     [ "WT_STAT_CONN_CACHE_BYTES_OTHER", "group__wt.html#ga1d3fe9c675cec7e6aed401db2a1266a3", null ],
     [ "WT_STAT_CONN_CACHE_BYTES_READ", "group__wt.html#gad2c8d2f65106a89c5582149626a62c23", null ],
@@ -210,10 +222,22 @@ var group__wt =
     [ "WT_STAT_CONN_CACHE_EVICTION_SPLIT_LEAF", "group__wt.html#ga4cc6f03ab41775215862fc7c8e8c0ff1", null ],
     [ "WT_STAT_CONN_CACHE_EVICTION_STABLE_STATE_WORKERS", "group__wt.html#ga7395ea1890d6cee6bdc069f9a31d709f", null ],
     [ "WT_STAT_CONN_CACHE_EVICTION_STATE", "group__wt.html#ga7399319fd6971d1feabfce2a9fe60623", null ],
+    [ "WT_STAT_CONN_CACHE_EVICTION_TARGET_PAGE_GE128", "group__wt.html#ga33883fdec5108a9e14dad7d6cec547e8", null ],
+    [ "WT_STAT_CONN_CACHE_EVICTION_TARGET_PAGE_LT10", "group__wt.html#ga16c72fa3964a29a346a29f4241b8a00e", null ],
+    [ "WT_STAT_CONN_CACHE_EVICTION_TARGET_PAGE_LT128", "group__wt.html#gadb31b97f4ef3c120e3647a68a343d941", null ],
+    [ "WT_STAT_CONN_CACHE_EVICTION_TARGET_PAGE_LT32", "group__wt.html#gaf06e3d1922fd7e5cf0f94234a204f939", null ],
+    [ "WT_STAT_CONN_CACHE_EVICTION_TARGET_PAGE_LT64", "group__wt.html#ga1de04b4105a236ef1e5fd14ac02dccbb", null ],
     [ "WT_STAT_CONN_CACHE_EVICTION_WALK", "group__wt.html#ga3e85a0cd390c4cf2ed3c578235c1f7d6", null ],
+    [ "WT_STAT_CONN_CACHE_EVICTION_WALK_FROM_ROOT", "group__wt.html#gafc073e2649aa13932f84c15d9df7e84d", null ],
+    [ "WT_STAT_CONN_CACHE_EVICTION_WALK_PASSES", "group__wt.html#ga6708fee683eedc5595b1ad2cd12a7269", null ],
+    [ "WT_STAT_CONN_CACHE_EVICTION_WALK_SAVED_POS", "group__wt.html#gaa856248a617951afd55125651ed5d83b", null ],
     [ "WT_STAT_CONN_CACHE_EVICTION_WALKS_ABANDONED", "group__wt.html#gadffd2bd9c5562dceb845af287e1e034e", null ],
     [ "WT_STAT_CONN_CACHE_EVICTION_WALKS_ACTIVE", "group__wt.html#ga49204374e4b4734e1346f4e2b497d726", null ],
+    [ "WT_STAT_CONN_CACHE_EVICTION_WALKS_ENDED", "group__wt.html#ga0006b95dec53ad4b45996062775caf59", null ],
+    [ "WT_STAT_CONN_CACHE_EVICTION_WALKS_GAVE_UP_NO_TARGETS", "group__wt.html#gacb03518dc92b78b9e37edd1e4d42d585", null ],
+    [ "WT_STAT_CONN_CACHE_EVICTION_WALKS_GAVE_UP_RATIO", "group__wt.html#gaf9a6e5c08c6bb1be91c0a74db722f7e5", null ],
     [ "WT_STAT_CONN_CACHE_EVICTION_WALKS_STARTED", "group__wt.html#ga5cc6a0e9c2fd7212845f6b1c94ff5be2", null ],
+    [ "WT_STAT_CONN_CACHE_EVICTION_WALKS_STOPPED", "group__wt.html#ga12a205788c24602df399defc92dc67dd", null ],
     [ "WT_STAT_CONN_CACHE_EVICTION_WORKER_CREATED", "group__wt.html#gab8249f83dca3b51b0d4fc1f9605b5345", null ],
     [ "WT_STAT_CONN_CACHE_EVICTION_WORKER_EVICTING", "group__wt.html#gafac92de6de839e9e528529adc328e01a", null ],
     [ "WT_STAT_CONN_CACHE_EVICTION_WORKER_REMOVED", "group__wt.html#gaef84b3e887ff46b2942b337f12689eab", null ],
@@ -222,9 +246,10 @@ var group__wt =
     [ "WT_STAT_CONN_CACHE_HAZARD_WALKS", "group__wt.html#gaaed5fd0a06d4df6d9a345c110c6471b0", null ],
     [ "WT_STAT_CONN_CACHE_INMEM_SPLIT", "group__wt.html#gac651643da398d7bcdabf205a12ca2c74", null ],
     [ "WT_STAT_CONN_CACHE_INMEM_SPLITTABLE", "group__wt.html#gaacd23e50c5c8815cf8687d9da6655ab4", null ],
+    [ "WT_STAT_CONN_CACHE_LOOKASIDE_ENTRIES", "group__wt.html#ga3e22557e3feb4488563db0160a8891d2", null ],
     [ "WT_STAT_CONN_CACHE_LOOKASIDE_INSERT", "group__wt.html#ga5b48117f3b0675390522d9104c9f62f5", null ],
     [ "WT_STAT_CONN_CACHE_LOOKASIDE_REMOVE", "group__wt.html#ga04bccbee64a4a75aa5e05a14365bde76", null ],
-    [ "WT_STAT_CONN_CACHE_OVERFLOW_VALUE", "group__wt.html#ga2f90904436d895de030af76fd9b0e4d4", null ],
+    [ "WT_STAT_CONN_CACHE_LOOKASIDE_SCORE", "group__wt.html#ga8ffe2e94e5c030e0a6f10e11c40c9da3", null ],
     [ "WT_STAT_CONN_CACHE_OVERHEAD", "group__wt.html#gaf8f0e2e86dee76423a1a51f6aee74018", null ],
     [ "WT_STAT_CONN_CACHE_PAGES_DIRTY", "group__wt.html#ga6a1cf2f6e874f367461426aeeb68ae3a", null ],
     [ "WT_STAT_CONN_CACHE_PAGES_INUSE", "group__wt.html#gab5a819ba891f98903ee2be2df3c565f1", null ],
@@ -232,27 +257,41 @@ var group__wt =
     [ "WT_STAT_CONN_CACHE_READ", "group__wt.html#ga9b00c2d4370db6216a7aaa7b7a6101d3", null ],
     [ "WT_STAT_CONN_CACHE_READ_APP_COUNT", "group__wt.html#ga8a73d792b5990146fb55d9e5ab336c01", null ],
     [ "WT_STAT_CONN_CACHE_READ_APP_TIME", "group__wt.html#ga895a7d761e1e60ba9896458c1d70d000", null ],
+    [ "WT_STAT_CONN_CACHE_READ_DELETED", "group__wt.html#ga6c8dd12c4309ce389014a84cd1105f4e", null ],
+    [ "WT_STAT_CONN_CACHE_READ_DELETED_PREPARED", "group__wt.html#ga10b195a4bf9b02aedeb766f9e8a4b03d", null ],
     [ "WT_STAT_CONN_CACHE_READ_LOOKASIDE", "group__wt.html#gaf9927116a3bd1b71cbaa626cb055a6ed", null ],
+    [ "WT_STAT_CONN_CACHE_READ_LOOKASIDE_CHECKPOINT", "group__wt.html#gaf7f1f7ab00b9f673370ef3766865d5fc", null ],
+    [ "WT_STAT_CONN_CACHE_READ_LOOKASIDE_DELAY", "group__wt.html#ga84714be9b21435088c27684129933cd4", null ],
+    [ "WT_STAT_CONN_CACHE_READ_LOOKASIDE_DELAY_CHECKPOINT", "group__wt.html#ga6a1727e746c2da276731462d2b22cbbd", null ],
+    [ "WT_STAT_CONN_CACHE_READ_LOOKASIDE_SKIPPED", "group__wt.html#ga44ba9fc07959271536d8d8e93df650eb", null ],
     [ "WT_STAT_CONN_CACHE_READ_OVERFLOW", "group__wt.html#gacde793f3bd5ccaf91b970852ed64da32", null ],
     [ "WT_STAT_CONN_CACHE_WRITE", "group__wt.html#ga94f3c473b10646f7ed3d047e275786db", null ],
     [ "WT_STAT_CONN_CACHE_WRITE_APP_COUNT", "group__wt.html#ga41d28222646d7848863cab2799e09d0c", null ],
     [ "WT_STAT_CONN_CACHE_WRITE_APP_TIME", "group__wt.html#ga4349484e45f9de41b63a085d52f88757", null ],
     [ "WT_STAT_CONN_CACHE_WRITE_LOOKASIDE", "group__wt.html#ga8857394274e973c900d7951d4ee9e663", null ],
     [ "WT_STAT_CONN_CACHE_WRITE_RESTORE", "group__wt.html#gab435a7372679c74261cb62624d953300", null ],
+    [ "WT_STAT_CONN_CHILD_MODIFY_BLOCKED_PAGE", "group__wt.html#ga8658fc3d52503f3228eac6ba33f2dec8", null ],
     [ "WT_STAT_CONN_COND_AUTO_WAIT", "group__wt.html#ga8cd96b5944d0ae8e331c3008643fa1fb", null ],
     [ "WT_STAT_CONN_COND_AUTO_WAIT_RESET", "group__wt.html#ga9db988882f3177840183ef1737a46335", null ],
     [ "WT_STAT_CONN_COND_WAIT", "group__wt.html#ga138063fbf1faaff0fd3b868244cb35a1", null ],
+    [ "WT_STAT_CONN_CONN_CLOSE_BLOCKED_LSM", "group__wt.html#ga7674ef83c36ef3703ad71503ad7193c5", null ],
+    [ "WT_STAT_CONN_CURSOR_CACHE", "group__wt.html#ga0648ab0a447dbfca1fab2808d3bcf579", null ],
     [ "WT_STAT_CONN_CURSOR_CREATE", "group__wt.html#ga4621505f48ba6399902a137ec0af556c", null ],
     [ "WT_STAT_CONN_CURSOR_INSERT", "group__wt.html#ga7fa6ef6ad4ec854de76565ebce34cede", null ],
     [ "WT_STAT_CONN_CURSOR_MODIFY", "group__wt.html#ga773c981e3f63f3341235a6f7c9e6320d", null ],
     [ "WT_STAT_CONN_CURSOR_NEXT", "group__wt.html#ga1b0c81ef9431dc6fc3a27f4880d579a9", null ],
     [ "WT_STAT_CONN_CURSOR_PREV", "group__wt.html#gafa8782397609778ea3efe002f85cb178", null ],
     [ "WT_STAT_CONN_CURSOR_REMOVE", "group__wt.html#ga5f26956f716badb7f59b7721b363244c", null ],
+    [ "WT_STAT_CONN_CURSOR_REOPEN", "group__wt.html#ga15eba675750acd1731c589fb1bd4e6a5", null ],
     [ "WT_STAT_CONN_CURSOR_RESERVE", "group__wt.html#ga477e927659d2ea724cfa4a2f56ddc6e4", null ],
     [ "WT_STAT_CONN_CURSOR_RESET", "group__wt.html#ga3949013afb46f95ea29ba5b33a36d771", null ],
     [ "WT_STAT_CONN_CURSOR_RESTART", "group__wt.html#ga786020eab331fbe646e733c1e8bcab4d", null ],
     [ "WT_STAT_CONN_CURSOR_SEARCH", "group__wt.html#gade710ac8febe12adefabcfaa119a54f5", null ],
     [ "WT_STAT_CONN_CURSOR_SEARCH_NEAR", "group__wt.html#gabc97d6575ac2ceae69af88c4031e0541", null ],
+    [ "WT_STAT_CONN_CURSOR_SWEEP", "group__wt.html#ga9b475ab7740c2918f246bfb69569f0db", null ],
+    [ "WT_STAT_CONN_CURSOR_SWEEP_BUCKETS", "group__wt.html#ga1191d1049828056513d57eff53c34976", null ],
+    [ "WT_STAT_CONN_CURSOR_SWEEP_CLOSED", "group__wt.html#ga0033cbf8339024705bfa2fe7d8ebc203", null ],
+    [ "WT_STAT_CONN_CURSOR_SWEEP_EXAMINED", "group__wt.html#ga8537fafa81d33c14901e8642a4d79759", null ],
     [ "WT_STAT_CONN_CURSOR_TRUNCATE", "group__wt.html#ga809fa186a02916a18838bf860b6173eb", null ],
     [ "WT_STAT_CONN_CURSOR_UPDATE", "group__wt.html#ga342eae1a0c6bbf8b7788f7e9fd5fc199", null ],
     [ "WT_STAT_CONN_DH_CONN_HANDLE_COUNT", "group__wt.html#gafd921e3c75db6fd7d8660bf6207e95be", null ],
@@ -263,11 +302,16 @@ var group__wt =
     [ "WT_STAT_CONN_DH_SWEEP_REMOVE", "group__wt.html#ga3b1ef579b3102bb360dfe0606e338658", null ],
     [ "WT_STAT_CONN_DH_SWEEP_TOD", "group__wt.html#gacb800123d59ba49f1a210befc62f377b", null ],
     [ "WT_STAT_CONN_DH_SWEEPS", "group__wt.html#ga05ee44b590869d161fc28a7e41c5acf2", null ],
+    [ "WT_STAT_CONN_DHANDLE_LOCK_BLOCKED", "group__wt.html#gac2b7bf415b251f0299803960b2ba82e3", null ],
     [ "WT_STAT_CONN_FILE_OPEN", "group__wt.html#gacb44b88acd3b00bee3236f9196f1b22e", null ],
     [ "WT_STAT_CONN_FSYNC_IO", "group__wt.html#ga43f1791f227e58e339d7bbc740b360dc", null ],
     [ "WT_STAT_CONN_LOCK_CHECKPOINT_COUNT", "group__wt.html#ga7a5a76edcd14f2011fd71045c891048c", null ],
     [ "WT_STAT_CONN_LOCK_CHECKPOINT_WAIT_APPLICATION", "group__wt.html#ga7eadee862b9f14d05551beb931e4c06d", null ],
     [ "WT_STAT_CONN_LOCK_CHECKPOINT_WAIT_INTERNAL", "group__wt.html#ga8b6c1c6d5e81affa83b418f47c774952", null ],
+    [ "WT_STAT_CONN_LOCK_COMMIT_TIMESTAMP_READ_COUNT", "group__wt.html#gac5500ef18e371f7ea61149b98cc54e1d", null ],
+    [ "WT_STAT_CONN_LOCK_COMMIT_TIMESTAMP_WAIT_APPLICATION", "group__wt.html#gad531cb17ab0bcdf2090c61ae57f6ed91", null ],
+    [ "WT_STAT_CONN_LOCK_COMMIT_TIMESTAMP_WAIT_INTERNAL", "group__wt.html#ga48ccec7f0ad8dce1240a2ccdd5e80964", null ],
+    [ "WT_STAT_CONN_LOCK_COMMIT_TIMESTAMP_WRITE_COUNT", "group__wt.html#ga92a3750baddd988ae670281308c47281", null ],
     [ "WT_STAT_CONN_LOCK_DHANDLE_READ_COUNT", "group__wt.html#ga8ada8a01f949465158a89204a1f62d30", null ],
     [ "WT_STAT_CONN_LOCK_DHANDLE_WAIT_APPLICATION", "group__wt.html#ga0d8fdfa31188f71b0003a2bbfcb8eac3", null ],
     [ "WT_STAT_CONN_LOCK_DHANDLE_WAIT_INTERNAL", "group__wt.html#ga46e21553168cee4df6fde841a3cd72c2", null ],
@@ -275,6 +319,10 @@ var group__wt =
     [ "WT_STAT_CONN_LOCK_METADATA_COUNT", "group__wt.html#gad9278b4a7515a3a60260a299bd36dece", null ],
     [ "WT_STAT_CONN_LOCK_METADATA_WAIT_APPLICATION", "group__wt.html#ga1a64a613da3cd133fac6f3f65d1d7675", null ],
     [ "WT_STAT_CONN_LOCK_METADATA_WAIT_INTERNAL", "group__wt.html#gad13ce2f113e1f074f72dfe7d282166bf", null ],
+    [ "WT_STAT_CONN_LOCK_READ_TIMESTAMP_READ_COUNT", "group__wt.html#ga472ffe8ae92d8bb083d497f73f58187c", null ],
+    [ "WT_STAT_CONN_LOCK_READ_TIMESTAMP_WAIT_APPLICATION", "group__wt.html#ga2f4cf362ee59423389e4d2252ed39ac9", null ],
+    [ "WT_STAT_CONN_LOCK_READ_TIMESTAMP_WAIT_INTERNAL", "group__wt.html#ga8d05dd70acd0e3e72a78e3392f95e7cf", null ],
+    [ "WT_STAT_CONN_LOCK_READ_TIMESTAMP_WRITE_COUNT", "group__wt.html#ga45ff74539e2c1f3bce3e1a23551bc94e", null ],
     [ "WT_STAT_CONN_LOCK_SCHEMA_COUNT", "group__wt.html#ga4eee9b9cafd39cde7bfa6b3906471e05", null ],
     [ "WT_STAT_CONN_LOCK_SCHEMA_WAIT_APPLICATION", "group__wt.html#ga753441131ce9566838f35e9d833a83db", null ],
     [ "WT_STAT_CONN_LOCK_SCHEMA_WAIT_INTERNAL", "group__wt.html#ga2734c2ce0f946fffc03c9483fadaa37a", null ],
@@ -282,6 +330,10 @@ var group__wt =
     [ "WT_STAT_CONN_LOCK_TABLE_WAIT_APPLICATION", "group__wt.html#gae4c4e8505a092c41eda36017a5ba2c13", null ],
     [ "WT_STAT_CONN_LOCK_TABLE_WAIT_INTERNAL", "group__wt.html#ga18b6b97b7a224b0fbc1def33eb8aaaeb", null ],
     [ "WT_STAT_CONN_LOCK_TABLE_WRITE_COUNT", "group__wt.html#ga88c990e679f93ecf486575014dfa6cc3", null ],
+    [ "WT_STAT_CONN_LOCK_TXN_GLOBAL_READ_COUNT", "group__wt.html#ga77e4d7ab151c245e62befb8925b5b236", null ],
+    [ "WT_STAT_CONN_LOCK_TXN_GLOBAL_WAIT_APPLICATION", "group__wt.html#ga059000421e4199c64229337aeb491355", null ],
+    [ "WT_STAT_CONN_LOCK_TXN_GLOBAL_WAIT_INTERNAL", "group__wt.html#ga7fa3d91a1604e83e96d2842a6f40b91f", null ],
+    [ "WT_STAT_CONN_LOCK_TXN_GLOBAL_WRITE_COUNT", "group__wt.html#gaea6e6db0450e8e530e2a5fdaec089eb4", null ],
     [ "WT_STAT_CONN_LOG_BUFFER_SIZE", "group__wt.html#ga7111b3912e9e1162ef965d0637e27b34", null ],
     [ "WT_STAT_CONN_LOG_BYTES_PAYLOAD", "group__wt.html#gae4c40f5b7376197e313972dd4e337758", null ],
     [ "WT_STAT_CONN_LOG_BYTES_WRITTEN", "group__wt.html#ga58af084ac45e0367be4492c50ffaadce", null ],
@@ -292,6 +344,7 @@ var group__wt =
     [ "WT_STAT_CONN_LOG_COMPRESS_WRITE_FAILS", "group__wt.html#gad866c0aefbf1f6351d1ea5a37d7f65de", null ],
     [ "WT_STAT_CONN_LOG_COMPRESS_WRITES", "group__wt.html#ga309dafb64c7e9e3d214ee9b73ec81d61", null ],
     [ "WT_STAT_CONN_LOG_FLUSH", "group__wt.html#ga3a28f511191b864b1a13b31d6bbfc80a", null ],
+    [ "WT_STAT_CONN_LOG_FORCE_ARCHIVE_SLEEP", "group__wt.html#ga1e3c3660877e8654c65e64d3ccc48ccc", null ],
     [ "WT_STAT_CONN_LOG_FORCE_WRITE", "group__wt.html#ga8b5a8a3421f8c074cb7ed768ca1a6b73", null ],
     [ "WT_STAT_CONN_LOG_FORCE_WRITE_SKIP", "group__wt.html#gafad1a15db915e22643108eed45558027", null ],
     [ "WT_STAT_CONN_LOG_MAX_FILESIZE", "group__wt.html#ga4ca1e771613773fb02c6d423415f6ffa", null ],
@@ -303,6 +356,7 @@ var group__wt =
     [ "WT_STAT_CONN_LOG_SCAN_RECORDS", "group__wt.html#ga01f2c3cc7b75a0c6548e25ecbc21864d", null ],
     [ "WT_STAT_CONN_LOG_SCAN_REREADS", "group__wt.html#ga7f3490d1b9432515759ded999fe0576c", null ],
     [ "WT_STAT_CONN_LOG_SCANS", "group__wt.html#gaeee33485a03b82a571f10726a8308eba", null ],
+    [ "WT_STAT_CONN_LOG_SERVER_SYNC_BLOCKED", "group__wt.html#ga2c6868733b8b13adf6c69131f694a1bd", null ],
     [ "WT_STAT_CONN_LOG_SLOT_ACTIVE_CLOSED", "group__wt.html#ga9b6100cd38b7b9cff35675958691c04b", null ],
     [ "WT_STAT_CONN_LOG_SLOT_CLOSE_RACE", "group__wt.html#ga0c9c07d97fa63d00491367d567ff244c", null ],
     [ "WT_STAT_CONN_LOG_SLOT_CLOSE_UNBUF", "group__wt.html#gafcec268457390a466878772052110af0", null ],
@@ -341,10 +395,35 @@ var group__wt =
     [ "WT_STAT_CONN_MEMORY_FREE", "group__wt.html#ga7a93dc65decc30c45536aefa1d622fcc", null ],
     [ "WT_STAT_CONN_MEMORY_GROW", "group__wt.html#ga9182ecd3b4d49d081d49ecb657a360bf", null ],
     [ "WT_STAT_CONN_PAGE_BUSY_BLOCKED", "group__wt.html#gab54ab74ebe4e861834a16402c3d5b1c4", null ],
+    [ "WT_STAT_CONN_PAGE_DEL_ROLLBACK_BLOCKED", "group__wt.html#ga8bb75989de2ec1cd9d00829ae9e9ef8d", null ],
     [ "WT_STAT_CONN_PAGE_FORCIBLE_EVICT_BLOCKED", "group__wt.html#ga6b3c415313e9a202152054926eba1b00", null ],
+    [ "WT_STAT_CONN_PAGE_INDEX_SLOT_REF_BLOCKED", "group__wt.html#gaa152f876f74d2f802c4f219e2ec201cb", null ],
     [ "WT_STAT_CONN_PAGE_LOCKED_BLOCKED", "group__wt.html#gadc9189970eb1cab5453c02bda892d8e1", null ],
     [ "WT_STAT_CONN_PAGE_READ_BLOCKED", "group__wt.html#gaa2dfc412b52c391ef8e44195223ab036", null ],
     [ "WT_STAT_CONN_PAGE_SLEEP", "group__wt.html#ga3fcc56ec891bd6e24675dc053397691b", null ],
+    [ "WT_STAT_CONN_PERF_HIST_FSREAD_LATENCY_GT1000", "group__wt.html#gacc3e81183d0ba7224963618ba0f86f91", null ],
+    [ "WT_STAT_CONN_PERF_HIST_FSREAD_LATENCY_LT100", "group__wt.html#gab69575a0f89fd8c413a7b183204be7b3", null ],
+    [ "WT_STAT_CONN_PERF_HIST_FSREAD_LATENCY_LT1000", "group__wt.html#gabd633e671069ea7c5f567af6677e2edb", null ],
+    [ "WT_STAT_CONN_PERF_HIST_FSREAD_LATENCY_LT250", "group__wt.html#ga8d08caf353b0128f29f1ebfdfcc29c0b", null ],
+    [ "WT_STAT_CONN_PERF_HIST_FSREAD_LATENCY_LT50", "group__wt.html#gacf77e58a01ad4a4c316be3abb2eb0233", null ],
+    [ "WT_STAT_CONN_PERF_HIST_FSREAD_LATENCY_LT500", "group__wt.html#ga61097987bcab9ff220f9a597c10150c4", null ],
+    [ "WT_STAT_CONN_PERF_HIST_FSWRITE_LATENCY_GT1000", "group__wt.html#ga70303b938fe2949c13884c1660179c5a", null ],
+    [ "WT_STAT_CONN_PERF_HIST_FSWRITE_LATENCY_LT100", "group__wt.html#ga3b9d70cff9680e4614c2dbe2c27a7c4c", null ],
+    [ "WT_STAT_CONN_PERF_HIST_FSWRITE_LATENCY_LT1000", "group__wt.html#ga9f2f8149523b1e6e4f64100ef198e050", null ],
+    [ "WT_STAT_CONN_PERF_HIST_FSWRITE_LATENCY_LT250", "group__wt.html#ga339fdee8a1b559af384b994c0952c0ad", null ],
+    [ "WT_STAT_CONN_PERF_HIST_FSWRITE_LATENCY_LT50", "group__wt.html#gad59d124a0e6bffb9919bc51697497df4", null ],
+    [ "WT_STAT_CONN_PERF_HIST_FSWRITE_LATENCY_LT500", "group__wt.html#ga0128cef518080b49f6b708060211943c", null ],
+    [ "WT_STAT_CONN_PERF_HIST_OPREAD_LATENCY_GT10000", "group__wt.html#gaaa43ca231e73ce343409891029299872", null ],
+    [ "WT_STAT_CONN_PERF_HIST_OPREAD_LATENCY_LT1000", "group__wt.html#gaf6f31e98a4b037443612d05c6f1442ab", null ],
+    [ "WT_STAT_CONN_PERF_HIST_OPREAD_LATENCY_LT10000", "group__wt.html#ga4ab807fdce0ca362e3ad1ebef0e77507", null ],
+    [ "WT_STAT_CONN_PERF_HIST_OPREAD_LATENCY_LT250", "group__wt.html#ga4d760a39df4232fb4c3e9308e21756a2", null ],
+    [ "WT_STAT_CONN_PERF_HIST_OPREAD_LATENCY_LT500", "group__wt.html#ga74bd29055199ef15085d2b1c6fd82ff6", null ],
+    [ "WT_STAT_CONN_PERF_HIST_OPWRITE_LATENCY_GT10000", "group__wt.html#ga4f2167c286f1f726286b2f20657dce63", null ],
+    [ "WT_STAT_CONN_PERF_HIST_OPWRITE_LATENCY_LT1000", "group__wt.html#ga73cac68702f3143f2146822c7398200a", null ],
+    [ "WT_STAT_CONN_PERF_HIST_OPWRITE_LATENCY_LT10000", "group__wt.html#ga10569cd0fb0f341aafb831504e182ec2", null ],
+    [ "WT_STAT_CONN_PERF_HIST_OPWRITE_LATENCY_LT250", "group__wt.html#gaff213856daa75fe9fa8c3fc46ed24141", null ],
+    [ "WT_STAT_CONN_PERF_HIST_OPWRITE_LATENCY_LT500", "group__wt.html#ga8251dd1f2fcdb83e3924d3db24beac92", null ],
+    [ "WT_STAT_CONN_PREPARED_TRANSITION_BLOCKED_PAGE", "group__wt.html#ga444f33af556b4f82d215f8e84b473199", null ],
     [ "WT_STAT_CONN_READ_IO", "group__wt.html#ga38f0e79fe5107b28a49a527b6b0639da", null ],
     [ "WT_STAT_CONN_REC_PAGE_DELETE", "group__wt.html#gae9a8a4250603ba105328c7a0a2dc6d7c", null ],
     [ "WT_STAT_CONN_REC_PAGE_DELETE_FAST", "group__wt.html#ga56aba145afb1b81789e11557a37dabc9", null ],
@@ -393,11 +472,37 @@ var group__wt =
     [ "WT_STAT_CONN_TXN_CHECKPOINT_TIME_RECENT", "group__wt.html#gaa0a189dbe2755d92eb90645bed73c7e7", null ],
     [ "WT_STAT_CONN_TXN_CHECKPOINT_TIME_TOTAL", "group__wt.html#ga5405afab183326ff46c852a237d57a41", null ],
     [ "WT_STAT_CONN_TXN_COMMIT", "group__wt.html#ga83162e41a1eede606d6319717c3a893b", null ],
+    [ "WT_STAT_CONN_TXN_COMMIT_QUEUE_EMPTY", "group__wt.html#gafe9ae696cf24a548b230b5bc7de43266", null ],
+    [ "WT_STAT_CONN_TXN_COMMIT_QUEUE_INSERTS", "group__wt.html#ga0e42c5ba33463da9910638a987e4283d", null ],
+    [ "WT_STAT_CONN_TXN_COMMIT_QUEUE_LEN", "group__wt.html#ga8a0431d26d4b1622369a5adb892469aa", null ],
+    [ "WT_STAT_CONN_TXN_COMMIT_QUEUE_TAIL", "group__wt.html#ga11576e004e511b6e3d93d3bda34dd4e6", null ],
     [ "WT_STAT_CONN_TXN_FAIL_CACHE", "group__wt.html#ga008e3e59a4d0c6f66a35ec52309033dc", null ],
     [ "WT_STAT_CONN_TXN_PINNED_CHECKPOINT_RANGE", "group__wt.html#ga3b31a429e052e74b05dd55787a8444b6", null ],
     [ "WT_STAT_CONN_TXN_PINNED_RANGE", "group__wt.html#ga4525377acdbf81d2ca804e347f967a80", null ],
     [ "WT_STAT_CONN_TXN_PINNED_SNAPSHOT_RANGE", "group__wt.html#ga157db9dbbcaa1d101064c007056ecf03", null ],
+    [ "WT_STAT_CONN_TXN_PINNED_TIMESTAMP", "group__wt.html#ga9f44ff6954d8f64698c73f6ff83517ff", null ],
+    [ "WT_STAT_CONN_TXN_PINNED_TIMESTAMP_OLDEST", "group__wt.html#ga595e980cdbabf4c5eef6077111727e22", null ],
+    [ "WT_STAT_CONN_TXN_PREPARE", "group__wt.html#ga235a8969a4c35c1661bafb8d288f7bd5", null ],
+    [ "WT_STAT_CONN_TXN_PREPARE_ACTIVE", "group__wt.html#ga4710dc41dd8f6487cfbd9411a1f48c5c", null ],
+    [ "WT_STAT_CONN_TXN_PREPARE_COMMIT", "group__wt.html#ga78b904803390302399c32d1da85690f9", null ],
+    [ "WT_STAT_CONN_TXN_PREPARE_ROLLBACK", "group__wt.html#gad33543a1462eb42e44251ea0800f7ebe", null ],
+    [ "WT_STAT_CONN_TXN_QUERY_TS", "group__wt.html#ga99702821df60ac2845a9c89a7c9bc1cb", null ],
+    [ "WT_STAT_CONN_TXN_READ_QUEUE_EMPTY", "group__wt.html#gadc8b613d73e776000e804218a0c0e3ff", null ],
+    [ "WT_STAT_CONN_TXN_READ_QUEUE_HEAD", "group__wt.html#gafdd933944ff0d27fbd8c95e65de8f209", null ],
+    [ "WT_STAT_CONN_TXN_READ_QUEUE_INSERTS", "group__wt.html#ga5e9b162d3bfe2557531d4b254727a7d7", null ],
+    [ "WT_STAT_CONN_TXN_READ_QUEUE_LEN", "group__wt.html#gaa1265659398b9349cd7f6e6e986e1dc1", null ],
+    [ "WT_STAT_CONN_TXN_RELEASE_BLOCKED", "group__wt.html#ga52df57d3185b8f38832d3a38584ef6a0", null ],
     [ "WT_STAT_CONN_TXN_ROLLBACK", "group__wt.html#gac59719438965d6f2f0c89df53676680b", null ],
+    [ "WT_STAT_CONN_TXN_ROLLBACK_LAS_REMOVED", "group__wt.html#ga6fd049adbd7a3d5c19e7703324f448d1", null ],
+    [ "WT_STAT_CONN_TXN_ROLLBACK_TO_STABLE", "group__wt.html#ga1fd0c5f56ad70d6dc00b4e433320e780", null ],
+    [ "WT_STAT_CONN_TXN_ROLLBACK_UPD_ABORTED", "group__wt.html#gaad44523254b502dd5dcfdb0d0ea46364", null ],
+    [ "WT_STAT_CONN_TXN_SET_TS", "group__wt.html#ga25777c1773b5be81573a121ac29b4d52", null ],
+    [ "WT_STAT_CONN_TXN_SET_TS_COMMIT", "group__wt.html#gaa77abf963e05dd0bce857414cc59776e", null ],
+    [ "WT_STAT_CONN_TXN_SET_TS_COMMIT_UPD", "group__wt.html#gabed827f2378e7d5c2802273fbe95406f", null ],
+    [ "WT_STAT_CONN_TXN_SET_TS_OLDEST", "group__wt.html#gab23bbcd9ab6a3eaac2d39aa29468fcfa", null ],
+    [ "WT_STAT_CONN_TXN_SET_TS_OLDEST_UPD", "group__wt.html#ga226c08ccaa6b368b3ec8dfbfc727d44a", null ],
+    [ "WT_STAT_CONN_TXN_SET_TS_STABLE", "group__wt.html#gab33d53b5c787f3ea35af0d11fb669d3c", null ],
+    [ "WT_STAT_CONN_TXN_SET_TS_STABLE_UPD", "group__wt.html#gab031f16842a914c8a9ac52d75e1ef353", null ],
     [ "WT_STAT_CONN_TXN_SNAPSHOTS_CREATED", "group__wt.html#ga219347d44f2b9701e6254f4a16fba1bf", null ],
     [ "WT_STAT_CONN_TXN_SNAPSHOTS_DROPPED", "group__wt.html#ga5e8806d6c13e997ff8f26b1d332d750d", null ],
     [ "WT_STAT_CONN_TXN_SYNC", "group__wt.html#gaf40fbeef46755a0c76d1755c4b63919f", null ],
@@ -449,15 +554,32 @@ var group__wt =
     [ "WT_STAT_DSRC_CACHE_EVICTION_FAIL", "group__wt.html#ga805d4bd189cdd57d212c4b5c138ad98e", null ],
     [ "WT_STAT_DSRC_CACHE_EVICTION_HAZARD", "group__wt.html#gaf92a2b38966634fe4588cb1d17c8bf8b", null ],
     [ "WT_STAT_DSRC_CACHE_EVICTION_INTERNAL", "group__wt.html#ga2a096a20eb52ebedd1972a32e8832d9d", null ],
+    [ "WT_STAT_DSRC_CACHE_EVICTION_PAGES_SEEN", "group__wt.html#ga95e26dd1e15f0352f1c8c05aaf1ab2b3", null ],
     [ "WT_STAT_DSRC_CACHE_EVICTION_SPLIT_INTERNAL", "group__wt.html#ga5db14276c869c64da7ff2985af57e255", null ],
     [ "WT_STAT_DSRC_CACHE_EVICTION_SPLIT_LEAF", "group__wt.html#gac7e5bdbc5f9b7d60d5021d9f72dbda8a", null ],
+    [ "WT_STAT_DSRC_CACHE_EVICTION_TARGET_PAGE_GE128", "group__wt.html#ga062b62d89969ff35bac653cb1247bc0e", null ],
+    [ "WT_STAT_DSRC_CACHE_EVICTION_TARGET_PAGE_LT10", "group__wt.html#ga922cff992f212271f62014228d362e42", null ],
+    [ "WT_STAT_DSRC_CACHE_EVICTION_TARGET_PAGE_LT128", "group__wt.html#ga2153192e5c8bc2a9f418cf112cf2d8fe", null ],
+    [ "WT_STAT_DSRC_CACHE_EVICTION_TARGET_PAGE_LT32", "group__wt.html#gae2639f12a4fc35a56a9d32f4a6e09a4e", null ],
+    [ "WT_STAT_DSRC_CACHE_EVICTION_TARGET_PAGE_LT64", "group__wt.html#ga48e5fec02cf858c0842c560f7002b4f9", null ],
+    [ "WT_STAT_DSRC_CACHE_EVICTION_WALK_FROM_ROOT", "group__wt.html#ga8781884a9122212585bd1ee8d0c44647", null ],
+    [ "WT_STAT_DSRC_CACHE_EVICTION_WALK_PASSES", "group__wt.html#gaa9064c56649bc3fdfc11bb7f7c5086fc", null ],
+    [ "WT_STAT_DSRC_CACHE_EVICTION_WALK_SAVED_POS", "group__wt.html#ga3d395bb08367040916f3d3d249eb8e45", null ],
+    [ "WT_STAT_DSRC_CACHE_EVICTION_WALKS_ABANDONED", "group__wt.html#ga68daa6578bd3ceff0f300d3d33891980", null ],
+    [ "WT_STAT_DSRC_CACHE_EVICTION_WALKS_ENDED", "group__wt.html#ga3e44a184ff711d51a61ef07092a2a5a3", null ],
+    [ "WT_STAT_DSRC_CACHE_EVICTION_WALKS_GAVE_UP_NO_TARGETS", "group__wt.html#ga909dc56db13de0ac9706564d507b81da", null ],
+    [ "WT_STAT_DSRC_CACHE_EVICTION_WALKS_GAVE_UP_RATIO", "group__wt.html#ga684aa1169dd6f53f816c9cec37819af1", null ],
+    [ "WT_STAT_DSRC_CACHE_EVICTION_WALKS_STOPPED", "group__wt.html#ga44437a326761711252f7f3ce44deab56", null ],
     [ "WT_STAT_DSRC_CACHE_INMEM_SPLIT", "group__wt.html#gaeb62f7da723e2089c0d829605d6f42e0", null ],
     [ "WT_STAT_DSRC_CACHE_INMEM_SPLITTABLE", "group__wt.html#ga476c96e900f1a66becc78adcd46c165b", null ],
-    [ "WT_STAT_DSRC_CACHE_OVERFLOW_VALUE", "group__wt.html#gac6664495c82449504117c0aa9798e707", null ],
     [ "WT_STAT_DSRC_CACHE_PAGES_REQUESTED", "group__wt.html#ga52a8e522caf9ce090d9a8b2708ff1d92", null ],
     [ "WT_STAT_DSRC_CACHE_READ", "group__wt.html#ga42c0304e959ce5786e8d4f6787465a08", null ],
+    [ "WT_STAT_DSRC_CACHE_READ_DELETED", "group__wt.html#ga4ed3e961b29792b394e782b502f81e7c", null ],
+    [ "WT_STAT_DSRC_CACHE_READ_DELETED_PREPARED", "group__wt.html#ga206aa7b3d554cb388480394bc5d7ab46", null ],
     [ "WT_STAT_DSRC_CACHE_READ_LOOKASIDE", "group__wt.html#gad3928585fe04068ea44325b7069ae3eb", null ],
     [ "WT_STAT_DSRC_CACHE_READ_OVERFLOW", "group__wt.html#gaddacd1ad56365226429fe28e4f338b42", null ],
+    [ "WT_STAT_DSRC_CACHE_STATE_AVG_UNVISITED_AGE", "group__wt.html#gad9b6a7ca6dab24ba529d50b1029537df", null ],
+    [ "WT_STAT_DSRC_CACHE_STATE_AVG_VISITED_AGE", "group__wt.html#gaf4ebaf8a947df722bd68d864e9c7f635", null ],
     [ "WT_STAT_DSRC_CACHE_STATE_AVG_WRITTEN_SIZE", "group__wt.html#gab77eab473228d9f548f0c57cde75f99d", null ],
     [ "WT_STAT_DSRC_CACHE_STATE_GEN_AVG_GAP", "group__wt.html#ga35cc96dfb2c728e0dfbcb406d56d8a8c", null ],
     [ "WT_STAT_DSRC_CACHE_STATE_GEN_CURRENT", "group__wt.html#ga6fd65e031f7dbbd88fe92ebcbc5503c6", null ],
@@ -476,6 +598,7 @@ var group__wt =
     [ "WT_STAT_DSRC_CACHE_STATE_ROOT_ENTRIES", "group__wt.html#ga37622ee476097218be4b2076a4a51a8f", null ],
     [ "WT_STAT_DSRC_CACHE_STATE_ROOT_SIZE", "group__wt.html#ga561d3e585c769f33aeba2de57cd5ec4c", null ],
     [ "WT_STAT_DSRC_CACHE_STATE_SMALLER_ALLOC_SIZE", "group__wt.html#gac2ca7cc07e141c44db8053f7da29c558", null ],
+    [ "WT_STAT_DSRC_CACHE_STATE_UNVISITED_COUNT", "group__wt.html#gaefb8db4b4e7f325499c51c140645a93e", null ],
     [ "WT_STAT_DSRC_CACHE_WRITE", "group__wt.html#ga4797cf2942d2c243f1341aa78dc50999", null ],
     [ "WT_STAT_DSRC_CACHE_WRITE_LOOKASIDE", "group__wt.html#ga6dda6ff62b477170ea60570e81ffc5f7", null ],
     [ "WT_STAT_DSRC_CACHE_WRITE_RESTORE", "group__wt.html#ga7430f63be721622674b32f35e50ec8a9", null ],
@@ -486,6 +609,7 @@ var group__wt =
     [ "WT_STAT_DSRC_COMPRESS_WRITE", "group__wt.html#ga63194c514dd5d46ccd6c6b6b3b13b221", null ],
     [ "WT_STAT_DSRC_COMPRESS_WRITE_FAIL", "group__wt.html#ga20cf6d95bc6fd56b34df9c3e69ddbacb", null ],
     [ "WT_STAT_DSRC_COMPRESS_WRITE_TOO_SMALL", "group__wt.html#gac56ee6a019093e4dc5813698b94ef27d", null ],
+    [ "WT_STAT_DSRC_CURSOR_CACHE", "group__wt.html#ga7c443b97283a1da5fad0896829dfe49b", null ],
     [ "WT_STAT_DSRC_CURSOR_CREATE", "group__wt.html#ga85524436e5af938e4f519aa2535e4e53", null ],
     [ "WT_STAT_DSRC_CURSOR_INSERT", "group__wt.html#gad83fd6d53789b73bb143f012614ac3cf", null ],
     [ "WT_STAT_DSRC_CURSOR_INSERT_BULK", "group__wt.html#ga37bb741ecdd7e0488da729e9d766bcdc", null ],
@@ -495,6 +619,7 @@ var group__wt =
     [ "WT_STAT_DSRC_CURSOR_PREV", "group__wt.html#gaa4c60f644f70674df35e2029dba167a9", null ],
     [ "WT_STAT_DSRC_CURSOR_REMOVE", "group__wt.html#gac92ab5e2c05538a95879edd25fddb0bd", null ],
     [ "WT_STAT_DSRC_CURSOR_REMOVE_BYTES", "group__wt.html#gaf9cc721c75f42a110e0f6af104087b4d", null ],
+    [ "WT_STAT_DSRC_CURSOR_REOPEN", "group__wt.html#ga7b88ef3d25e222b663cbee1eaf7ad05a", null ],
     [ "WT_STAT_DSRC_CURSOR_RESERVE", "group__wt.html#ga5bfe239f0975580e144b0ec6f34d3a30", null ],
     [ "WT_STAT_DSRC_CURSOR_RESET", "group__wt.html#ga797b44171cc04051876599882ba4f017", null ],
     [ "WT_STAT_DSRC_CURSOR_RESTART", "group__wt.html#ga79b1f83d582f8af473b0a2394f474a39", null ],
@@ -523,6 +648,7 @@ var group__wt =
     [ "WT_STAT_DSRC_REC_PREFIX_COMPRESSION", "group__wt.html#ga76e1013024e2e87cbe93cfa07e6e4bac", null ],
     [ "WT_STAT_DSRC_REC_SUFFIX_COMPRESSION", "group__wt.html#ga3eee70bbc9c9868267e4bb01e00b4e6a", null ],
     [ "WT_STAT_DSRC_SESSION_COMPACT", "group__wt.html#gae3a08df82d5b3571c61bed609980f845", null ],
+    [ "WT_STAT_DSRC_SESSION_CURSOR_CACHED", "group__wt.html#gafe4675c56c3dcbdd14dd8b5444894b6c", null ],
     [ "WT_STAT_DSRC_SESSION_CURSOR_OPEN", "group__wt.html#ga2aaf905ea64ae1f27393b5a84582b3fc", null ],
     [ "WT_STAT_DSRC_TXN_UPDATE_CONFLICT", "group__wt.html#gab3edfe41012927e52357fc5a723b4e85", null ],
     [ "WT_STAT_JOIN_BLOOM_FALSE_POSITIVE", "group__wt.html#ga328dbfa667ae495091818314972a667c", null ],
@@ -539,8 +665,9 @@ var group__wt =
       [ "WT_AOP_SEARCH", "group__wt.html#gga24152c6e1509c488192df653d511a82ca0a70cdcda8801256cc086e8ab7d78b44", null ],
       [ "WT_AOP_UPDATE", "group__wt.html#gga24152c6e1509c488192df653d511a82ca6b24879fd4e50bb05a4c53e443c5f390", null ]
     ] ],
+    [ "wiredtiger_checksum_crc32c", "group__wt.html#ga7edad34ec38545508ee2436c61e47b82", null ],
     [ "wiredtiger_config_parser_open", "group__wt.html#ga512297da65ccc30ac91bf6adf95f043f", null ],
-    [ "wiredtiger_open", "group__wt.html#ga9e6adae3fc6964ef837a62795c7840ed", null ],
+    [ "wiredtiger_open", "group__wt.html#gacbe8d118f978f5bfc8ccb4c77c9e8813", null ],
     [ "wiredtiger_pack_close", "group__wt.html#gad506573d475f00f3e6aae9ce36d8bc53", null ],
     [ "wiredtiger_pack_int", "group__wt.html#gad939363f1fa51697062d10d06e42fcca", null ],
     [ "wiredtiger_pack_item", "group__wt.html#ga94e4c63cd5cc0a714ede12431a8e228c", null ],
@@ -548,9 +675,9 @@ var group__wt =
     [ "wiredtiger_pack_str", "group__wt.html#ga1039d39f6e34ed3ab0964f581b4cd013", null ],
     [ "wiredtiger_pack_uint", "group__wt.html#ga2ed9313371aeee5334edb751df23992e", null ],
     [ "wiredtiger_strerror", "group__wt.html#gae8bf720ddb4a7a7390b70424594c40fd", null ],
-    [ "wiredtiger_struct_pack", "group__wt.html#ga58d055cb4d054715bebd58a2cb713b2d", null ],
-    [ "wiredtiger_struct_size", "group__wt.html#ga2460e8022f3c8c7cb5f274ec9f1764e6", null ],
-    [ "wiredtiger_struct_unpack", "group__wt.html#ga1db8298185374dbb61b398a4e9a3d1c8", null ],
+    [ "wiredtiger_struct_pack", "group__wt.html#gab3d8a22e243360ece67baf33926d80fa", null ],
+    [ "wiredtiger_struct_size", "group__wt.html#ga156e7993d370495e1e52c29b2bb6b7d4", null ],
+    [ "wiredtiger_struct_unpack", "group__wt.html#ga7cdc8c688f2c15303188ed6999dcc1b4", null ],
     [ "wiredtiger_unpack_int", "group__wt.html#ga6bb9dbe835af62495c1de4f31eb6ec49", null ],
     [ "wiredtiger_unpack_item", "group__wt.html#gade96c761e77521b46ba9d5fc455b3486", null ],
     [ "wiredtiger_unpack_start", "group__wt.html#gad93973bfd0e21ba845878ba3c4b97d96", null ],
