@@ -73,12 +73,16 @@ var group__wt__java =
       [ "async_new_op", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a76c8444703541803fab4bc54606136ed", null ],
       [ "close", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a2458441ed6301620ef4db71f3ef5c47c", null ],
       [ "configure_method", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a1b9848afb4bfe4b790579490e6e2263c", null ],
+      [ "debug_info", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#af0d653b71e7fede300bea53337323087", null ],
       [ "delete", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a0e8af34ebdff2b71b682095ed085cebe", null ],
       [ "get_home", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#ad52f0d0c36bcedfa2214f233f3ee020a", null ],
       [ "is_new", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a7ba72791fba4a03984c0d9b8faca1284", null ],
       [ "load_extension", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a1c404c400a9873926810241ad0997a4a", null ],
       [ "open_session", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#ad03cfc01de34342ab8c76934accb8745", null ],
+      [ "query_timestamp", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a77d25707d0ce76799a8b8d61f84b6a97", null ],
       [ "reconfigure", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a5e67d007427eb9a0b1c749b8c85468e2", null ],
+      [ "rollback_to_stable", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#aa133f587176b4510a753e1dc950fa5fc", null ],
+      [ "set_timestamp", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a84403030d0ef4f986544dda57498a1b4", null ],
       [ "swigCMemOwn", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a31658ee0e58784dd785b7226b1309476", null ]
     ] ],
     [ "Cursor", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html", [
@@ -168,6 +172,7 @@ var group__wt__java =
       [ "_java_init", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a849ad022f16375699c7dd625b80cc7e8", null ],
       [ "alter", "classcom_1_1wiredtiger_1_1db_1_1_session.html#aabeba4de10b95083dae3c73b7172e4a7", null ],
       [ "begin_transaction", "classcom_1_1wiredtiger_1_1db_1_1_session.html#abda8ddc193622bedbe6fba26e061405a", null ],
+      [ "breakpoint", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a14615b126a4824d04b7126b69ce5db6a", null ],
       [ "checkpoint", "classcom_1_1wiredtiger_1_1db_1_1_session.html#ae8a3a848702a49b9c3cb8e1ed1c1afd3", null ],
       [ "close", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a575d56d4413369b3db49bfeac3ff4caa", null ],
       [ "commit_transaction", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a707380a753afffb89b3195c16938ce8f", null ],
@@ -178,8 +183,9 @@ var group__wt__java =
       [ "getConnection", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a2f267cf49f92a76b4bad57015a05ba88", null ],
       [ "join", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a75ec87d13d61c38312f6097e86470b22", null ],
       [ "log_flush", "classcom_1_1wiredtiger_1_1db_1_1_session.html#ac8790893082bc6ca34ca288008971944", null ],
-      [ "log_printf", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a094ae49ac5f0533817961284c89b8327", null ],
+      [ "log_printf", "classcom_1_1wiredtiger_1_1db_1_1_session.html#acf3ea0aa8ef9a33416409fa8b8da80ae", null ],
       [ "open_cursor", "classcom_1_1wiredtiger_1_1db_1_1_session.html#adc61edbe05447e070a2d0729bd36a084", null ],
+      [ "prepare_transaction", "classcom_1_1wiredtiger_1_1db_1_1_session.html#aa824eb8055b405d362997a1ccdb3ea1a", null ],
       [ "rebalance", "classcom_1_1wiredtiger_1_1db_1_1_session.html#ae8e72b903d72a3ca1f1a0dd019c186d7", null ],
       [ "reconfigure", "classcom_1_1wiredtiger_1_1db_1_1_session.html#ab26e9fa8589c722544049adae0e70ad9", null ],
       [ "rename", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a2acb7e037b0d4bf9c8d812d264376465", null ],
@@ -188,6 +194,7 @@ var group__wt__java =
       [ "salvage", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a4687837f13f03699d9c295fdd4380398", null ],
       [ "snapshot", "classcom_1_1wiredtiger_1_1db_1_1_session.html#aa9c59ebe27793654d9a6206f28344809", null ],
       [ "strerror", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a0d3664f22568a5b36bece98592cb6ea4", null ],
+      [ "timestamp_transaction", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a8a7c42b78d550fd51a955cd336c39e43", null ],
       [ "transaction_pinned_range", "classcom_1_1wiredtiger_1_1db_1_1_session.html#aed31a501ee163947de5a82f2b31b03b9", null ],
       [ "transaction_sync", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a65ecc08c6b9d27bb108dd5bdac93b8a3", null ],
       [ "truncate", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a2c58845dfd2f75cc3935185c12d29329", null ],
