@@ -20,12 +20,12 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 ".html",
-"classcom_1_1wiredtiger_1_1db_1_1_pack_input_stream.html#a5b57caf554b40246549d2aa6a2da72d9",
-"durability_lang_java.html#durability_bulk_lang_java",
-"group__wt.html#ga43f1791f227e58e339d7bbc740b360dc",
-"group__wt.html#gad93973bfd0e21ba845878ba3c4b97d96",
-"struct_w_t___c_o_n_n_e_c_t_i_o_n.html#a0cfd7bfb13c5b2ad8499f44e43d62672",
-"tune_system_buffer_cache.html#tuning_system_buffer_cache_os_cache_dirty_max"
+"classcom_1_1wiredtiger_1_1db_1_1_pack_input_stream.html",
+"durability.html",
+"group__wt.html#ga33ac35e64c48896c09905f7b5e7068d4",
+"group__wt.html#ga9f2f8149523b1e6e4f64100ef198e050",
+"license.html#license_distribution",
+"struct_w_t___f_i_l_e___h_a_n_d_l_e.html#a350e1db2cd51c8c2479b03beae9af90f"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
