@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2014-2017 MongoDB, Inc.
+ * Copyright (c) 2014-2018 MongoDB, Inc.
  * Copyright (c) 2008-2014 WiredTiger, Inc.
  *	All rights reserved.
  *
@@ -8,6 +8,34 @@
 
 #define	WT_RECNO_OOB	0		/* Illegal record number */
 
+/* AUTOMATIC FLAG VALUE GENERATION START */
+#define	WT_READ_CACHE			0x0001u
+#define	WT_READ_DELETED_CHECK		0x0002u
+#define	WT_READ_DELETED_SKIP		0x0004u
+#define	WT_READ_IGNORE_CACHE_SIZE	0x0008u
+#define	WT_READ_LOOKASIDE		0x0010u
+#define	WT_READ_NOTFOUND_OK		0x0020u
+#define	WT_READ_NO_GEN			0x0040u
+#define	WT_READ_NO_SPLIT		0x0080u
+#define	WT_READ_NO_WAIT			0x0100u
+#define	WT_READ_PREV			0x0200u
+#define	WT_READ_RESTART_OK		0x0400u
+#define	WT_READ_SKIP_INTL		0x0800u
+#define	WT_READ_TRUNCATE		0x1000u
+#define	WT_READ_WONT_NEED		0x2000u
+/* AUTOMATIC FLAG VALUE GENERATION STOP */
+
+/* AUTOMATIC FLAG VALUE GENERATION START */
+#define	WT_REC_CHECKPOINT	0x01u
+#define	WT_REC_EVICT		0x02u
+#define	WT_REC_IN_MEMORY	0x04u
+#define	WT_REC_LOOKASIDE	0x08u
+#define	WT_REC_SCRUB		0x10u
+#define	WT_REC_UPDATE_RESTORE	0x20u
+#define	WT_REC_VISIBILITY_ERR	0x40u
+#define	WT_REC_VISIBLE_ALL	0x80u
+/* AUTOMATIC FLAG VALUE GENERATION STOP */
+
 /*
  * WT_PAGE_HEADER --
  *	Blocks have a common header, a WT_PAGE_HEADER structure followed by a
@@ -41,11 +69,15 @@ struct __wt_page_header {
 
 	uint8_t type;			/* 24: page type */
 
-#define	WT_PAGE_COMPRESSED	0x01	/* Page is compressed on disk */
-#define	WT_PAGE_EMPTY_V_ALL	0x02	/* Page has all zero-length values */
-#define	WT_PAGE_EMPTY_V_NONE	0x04	/* Page has no zero-length values */
-#define	WT_PAGE_ENCRYPTED	0x08	/* Page is encrypted on disk */
-#define	WT_PAGE_LAS_UPDATE	0x10	/* Page updates in lookaside store */
+	/*
+	 * No automatic generation: flag values cannot change, they're written
+	 * to disk.
+	 */
+#define	WT_PAGE_COMPRESSED	0x01u	/* Page is compressed on disk */
+#define	WT_PAGE_EMPTY_V_ALL	0x02u	/* Page has all zero-length values */
+#define	WT_PAGE_EMPTY_V_NONE	0x04u	/* Page has no zero-length values */
+#define	WT_PAGE_ENCRYPTED	0x08u	/* Page is encrypted on disk */
+#define	WT_PAGE_LAS_UPDATE	0x10u	/* Page updates in lookaside store */
 	uint8_t flags;			/* 25: flags */
 
 	/*
@@ -145,8 +177,10 @@ struct __wt_ovfl_reuse {
 	 * skiplist entry; if reconciliation fails for any reason, discard the
 	 * newly added skiplist entries, along with their underlying blocks.
 	 */
-#define	WT_OVFL_REUSE_INUSE		0x01
-#define	WT_OVFL_REUSE_JUST_ADDED	0x02
+/* AUTOMATIC FLAG VALUE GENERATION START */
+#define	WT_OVFL_REUSE_INUSE		0x1u
+#define	WT_OVFL_REUSE_JUST_ADDED	0x2u
+/* AUTOMATIC FLAG VALUE GENERATION STOP */
 	uint8_t	 flags;
 
 	/*
@@ -161,42 +195,18 @@ struct __wt_ovfl_reuse {
 	WT_OVFL_REUSE *next[0];		/* Forward-linked skip list */
 };
 
-/*
- * Overflow tracking for cached values: When a page is reconciled, we write new
- * K/V overflow items, and discard previous underlying blocks.  If there's a
- * transaction in the system that needs to read the previous value, we have to
- * cache the old value until no running transaction needs it.
- */
-struct __wt_ovfl_txnc {
-	uint64_t current;		/* Maximum transaction ID at store */
-
-	uint32_t value_offset;		/* Overflow value offset */
-	uint32_t value_size;		/* Overflow value size */
-	uint8_t  addr_offset;		/* Overflow addr offset */
-	uint8_t  addr_size;		/* Overflow addr size */
-
-	/*
-	 * The untyped address immediately follows the WT_OVFL_TXNC
-	 * structure, the untyped value immediately follows the address.
-	 */
-#define	WT_OVFL_TXNC_ADDR(p)						\
-	((void *)((uint8_t *)(p) + (p)->addr_offset))
-#define	WT_OVFL_TXNC_VALUE(p)						\
-	((void *)((uint8_t *)(p) + (p)->value_offset))
-
-	WT_OVFL_TXNC *next[0];		/* Forward-linked skip list */
-};
-
 /*
  * Lookaside table support: when a page is being reconciled for eviction and has
  * updates that might be required by earlier readers in the system, the updates
  * are written into a lookaside table, and restored as necessary if the page is
- * read. The key is a unique marker for the page (a file ID plus an address),
- * a counter (used to ensure the update records remain in the original order),
- * the on-page item's transaction ID (so we can discard any update records from
- * the lookaside table once the on-page item's transaction is globally visible),
- * and the page key (byte-string for row-store, record number for column-store).
- * The value is the WT_UPDATE structure's transaction ID, update size and value.
+ * read.
+ *
+ * The key is a unique marker for the page (a page ID plus a file ID, ordered
+ * this way so that overall the lookaside table is append-mostly), a counter
+ * (used to ensure the update records remain in the original order), and the
+ * record's key (byte-string for row-store, record number for column-store).
+ * The value is the WT_UPDATE structure's transaction ID, timestamp, update
+ * type and value.
  *
  * As the key for the lookaside table is different for row- and column-store, we
  * store both key types in a WT_ITEM, building/parsing them in the code, because
@@ -206,9 +216,33 @@ struct __wt_ovfl_txnc {
  * makes the lookaside table's value more likely to overflow the page size when
  * the row-store key is relatively large.
  */
-#define	WT_LAS_FORMAT							\
-    "key_format=" WT_UNCHECKED_STRING(IuQQu)				\
-    ",value_format=" WT_UNCHECKED_STRING(QBu)
+#ifdef HAVE_BUILTIN_EXTENSION_SNAPPY
+#define	WT_LOOKASIDE_COMPRESSOR	"snappy"
+#else
+#define	WT_LOOKASIDE_COMPRESSOR	"none"
+#endif
+#define	WT_LAS_CONFIG							\
+    "key_format=" WT_UNCHECKED_STRING(QIQu)				\
+    ",value_format=" WT_UNCHECKED_STRING(QuBu)				\
+    ",block_compressor=" WT_LOOKASIDE_COMPRESSOR			\
+    ",leaf_value_max=64MB"						\
+    ",prefix_compression=true"
+
+/*
+ * WT_PAGE_LOOKASIDE --
+ *	Related information for on-disk pages with lookaside entries.
+ */
+struct __wt_page_lookaside {
+	uint64_t las_pageid;		/* Page ID in lookaside */
+	uint64_t las_max_txn;		/* Max transaction ID in lookaside */
+	uint64_t las_min_txn;		/* Min transaction ID in lookaside */
+	WT_DECL_TIMESTAMP(min_timestamp)/* Min timestamp in lookaside */
+					/* Max timestamp on page */
+	WT_DECL_TIMESTAMP(onpage_timestamp)
+	bool eviction_to_lookaside;	/* Revert to lookaside on eviction */
+	bool las_skew_newest;		/* On-page skewed to newest */
+	bool invalid;			/* History is required correct reads */
+};
 
 /*
  * WT_PAGE_MODIFY --
@@ -219,7 +253,9 @@ struct __wt_page_modify {
 	uint64_t first_dirty_txn;
 
 	/* The transaction state last time eviction was attempted. */
+	uint64_t last_evict_pass_gen;
 	uint64_t last_eviction_id;
+	WT_DECL_TIMESTAMP(last_eviction_timestamp)
 
 #ifdef HAVE_DIAGNOSTIC
 	/* Check that transaction time moves forward. */
@@ -228,9 +264,11 @@ struct __wt_page_modify {
 
 	/* Avoid checking for obsolete updates during checkpoints. */
 	uint64_t obsolete_check_txn;
+	WT_DECL_TIMESTAMP(obsolete_check_timestamp)
 
-	/* The largest transaction ID seen on the page by reconciliation. */
+	/* The largest transaction seen on the page by reconciliation. */
 	uint64_t rec_max_txn;
+	WT_DECL_TIMESTAMP(rec_max_timestamp)
 
 	/* The largest update transaction ID (approximate). */
 	uint64_t update_txn;
@@ -263,11 +301,16 @@ struct __wt_page_modify {
 		 * re-instantiate the page in memory.
 		 */
 		void	*disk_image;
+
+		/* The page has lookaside entries. */
+		WT_PAGE_LOOKASIDE page_las;
 	} r;
 #undef	mod_replace
 #define	mod_replace	u1.r.replace
 #undef	mod_disk_image
 #define	mod_disk_image	u1.r.disk_image
+#undef	mod_page_las
+#define	mod_page_las	u1.r.page_las
 
 	struct {			/* Multiple replacement blocks */
 	struct __wt_multi {
@@ -287,18 +330,18 @@ struct __wt_page_modify {
 		void	*disk_image;
 
 		/*
-		 * List of unresolved updates. Updates are either a WT_INSERT
-		 * or a row-store leaf page entry; when creating lookaside
-		 * records, there is an additional value, the committed item's
-		 * transaction ID.
+		 * List of unresolved updates. Updates are either a row-store
+		 * insert or update list, or column-store insert list. When
+		 * creating lookaside records, there is an additional value,
+		 * the committed item's transaction information.
 		 *
 		 * If there are unresolved updates, the block wasn't written and
 		 * there will always be a disk image.
 		 */
 		struct __wt_save_upd {
-			WT_INSERT *ins;
-			WT_ROW	  *rip;
-			uint64_t   onpage_txn;
+			WT_INSERT *ins;		/* Insert list reference */
+			WT_ROW	  *ripcip;	/* Original on-page reference */
+			WT_UPDATE *onpage_upd;
 		} *supd;
 		uint32_t supd_entries;
 
@@ -312,6 +355,8 @@ struct __wt_page_modify {
 		WT_ADDR	 addr;
 		uint32_t size;
 		uint32_t checksum;
+
+		WT_PAGE_LOOKASIDE page_las;
 	} *multi;
 	uint32_t multi_entries;		/* Multiple blocks element count */
 	} m;
@@ -399,12 +444,6 @@ struct __wt_page_modify {
 		 */
 		WT_OVFL_REUSE	*ovfl_reuse[WT_SKIP_MAXDEPTH];
 
-		/*
-		 * Overflow value address/byte-string pairs cached until no
-		 * running transaction will possibly read them.
-		 */
-		WT_OVFL_TXNC	*ovfl_txnc[WT_SKIP_MAXDEPTH];
-
 		/*
 		 * Overflow key/value addresses to be discarded from the block
 		 * manager after reconciliation completes successfully.
@@ -412,6 +451,15 @@ struct __wt_page_modify {
 		WT_CELL **discard;
 		size_t	  discard_entries;
 		size_t	  discard_allocated;
+
+		/* Cached overflow value cell/update address pairs. */
+		struct {
+			WT_CELL	*cell;
+			uint8_t	*data;
+			size_t	 size;
+		} *remove;
+		size_t	 remove_allocated;
+		uint32_t remove_next;
 	} *ovfl_track;
 
 #define	WT_PAGE_LOCK(s, p) 						\
@@ -460,11 +508,7 @@ struct __wt_page {
 		 * Internal pages (both column- and row-store).
 		 *
 		 * In-memory internal pages have an array of pointers to child
-		 * structures, maintained in collated order.  When a page is
-		 * read into memory, the initial list of children is stored in
-		 * the "orig_index" field, and it and the collated order are
-		 * the same.  After a page splits, the collated order and the
-		 * original order will differ.
+		 * structures, maintained in collated order.
 		 *
 		 * Multiple threads of control may be searching the in-memory
 		 * internal page and a child page of the internal page may
@@ -594,13 +638,16 @@ struct __wt_page {
 #define	WT_PAGE_ROW_LEAF	7	/* Row-store leaf page */
 	uint8_t type;			/* Page type */
 
-#define	WT_PAGE_BUILD_KEYS	0x01	/* Keys have been built in memory */
-#define	WT_PAGE_DISK_ALLOC	0x02	/* Disk image in allocated memory */
-#define	WT_PAGE_DISK_MAPPED	0x04	/* Disk image in mapped memory */
-#define	WT_PAGE_EVICT_LRU	0x08	/* Page is on the LRU queue */
-#define	WT_PAGE_OVERFLOW_KEYS	0x10	/* Page has overflow keys */
-#define	WT_PAGE_SPLIT_INSERT	0x20	/* A leaf page was split for append */
-#define	WT_PAGE_UPDATE_IGNORE	0x40	/* Ignore updates on page discard */
+/* AUTOMATIC FLAG VALUE GENERATION START */
+#define	WT_PAGE_BUILD_KEYS	0x01u	/* Keys have been built in memory */
+#define	WT_PAGE_DISK_ALLOC	0x02u	/* Disk image in allocated memory */
+#define	WT_PAGE_DISK_MAPPED	0x04u	/* Disk image in mapped memory */
+#define	WT_PAGE_EVICT_LRU	0x08u	/* Page is on the LRU queue */
+#define	WT_PAGE_EVICT_NO_PROGRESS 0x10u	/* Eviction doesn't count as progress */
+#define	WT_PAGE_OVERFLOW_KEYS	0x20u	/* Page has overflow keys */
+#define	WT_PAGE_SPLIT_INSERT	0x40u	/* A leaf page was split for append */
+#define	WT_PAGE_UPDATE_IGNORE	0x80u	/* Ignore updates on page discard */
+/* AUTOMATIC FLAG VALUE GENERATION STOP */
 	uint8_t flags_atomic;		/* Atomic flags, use F_*_ATOMIC */
 
 	uint8_t unused[2];		/* Unused padding */
@@ -627,6 +674,9 @@ struct __wt_page {
 	 */
 #define	WT_READGEN_NOTSET	0
 #define	WT_READGEN_OLDEST	1
+#define	WT_READGEN_WONT_NEED	2
+#define	WT_READGEN_EVICT_SOON(readgen) 					\
+	((readgen) != WT_READGEN_NOTSET && (readgen) < WT_READGEN_START_VALUE)
 #define	WT_READGEN_START_VALUE	100
 #define	WT_READGEN_STEP		100
 	uint64_t read_gen;
@@ -641,6 +691,7 @@ struct __wt_page {
 
 	/* This is the 64 byte boundary, try to keep hot fields above here. */
 
+	uint64_t cache_create_gen;	/* Page create timestamp */
 	uint64_t evict_pass_gen;	/* Eviction pass generation */
 };
 
@@ -653,6 +704,45 @@ struct __wt_page {
 #define	WT_PAGE_REF_OFFSET(page, o)					\
 	((void *)((uint8_t *)((page)->dsk) + (o)))
 
+/*
+ * Prepare update states.
+ *
+ * Prepare update synchronization is based on the state field, which has the
+ * following possible states:
+ *
+ * WT_PREPARE_INIT:
+ *	The initial prepare state of either an update or a page_del structure,
+ *	indicating a prepare phase has not started yet.
+ *	This state has no impact on the visibility of the update's data.
+ *
+ * WT_PREPARE_INPROGRESS:
+ *	Update is in prepared phase.
+ *
+ * WT_PREPARE_LOCKED:
+ *	State is locked as state transition is in progress from INPROGRESS to
+ *	RESOLVED. Any reader of the state needs to wait for state transition to
+ *	complete.
+ *
+ * WT_PREPARE_RESOLVED:
+ *	Represents the commit state of the prepared update.
+ *
+ * State Transition:
+ * 	From uncommitted -> prepare -> commit:
+ * 	INIT --> INPROGRESS --> LOCKED --> RESOLVED
+ * 	LOCKED will be a momentary phase during timestamp update.
+ *
+ * 	From uncommitted -> prepare -> rollback:
+ * 	INIT --> INPROGRESS
+ * 	Prepare state will not be updated during rollback and will continue to
+ * 	have the state as INPROGRESS.
+ */
+#define	WT_PREPARE_INIT			0	/* Must be 0, as structures
+						   will be default initialized
+						   with 0. */
+#define	WT_PREPARE_INPROGRESS		1
+#define	WT_PREPARE_LOCKED		2
+#define	WT_PREPARE_RESOLVED		3
+
 /*
  * Page state.
  *
@@ -670,6 +760,10 @@ struct __wt_page {
  *	row-store leaf pages without reading them if they don't reference
  *	overflow items.
  *
+ * WT_REF_LIMBO:
+ *	The page image has been loaded into memory but there is additional
+ *	history in the lookaside table that has not been applied.
+ *
  * WT_REF_LOCKED:
  *	Locked for exclusive access.  In eviction, this page or a parent has
  *	been selected for eviction; once hazard pointers are checked, the page
@@ -678,6 +772,10 @@ struct __wt_page {
  *	thread that set the page to WT_REF_LOCKED has exclusive access, no
  *	other thread may use the WT_REF until the state is changed.
  *
+ * WT_REF_LOOKASIDE:
+ *	The page is on disk (as per WT_REF_DISK) and has entries in the
+ *	lookaside table that must be applied before the page can be read.
+ *
  * WT_REF_MEM:
  *	Set by a reading thread once the page has been read from disk; the page
  *	is in the cache and the page reference is OK.
@@ -712,12 +810,21 @@ struct __wt_page {
 
 /*
  * WT_PAGE_DELETED --
- *	Related information for fast-delete, on-disk pages.
+ *	Related information for truncated pages.
  */
 struct __wt_page_deleted {
-	uint64_t txnid;			/* Transaction ID */
+	volatile uint64_t txnid;		/* Transaction ID */
+	WT_DECL_TIMESTAMP(timestamp)
 
-	WT_UPDATE **update_list;	/* List of updates for abort */
+	/*
+	 * The state is used for transaction prepare to manage visibility
+	 * and inheriting prepare state to update_list.
+	 */
+	volatile uint8_t prepare_state;		/* Prepare state. */
+
+	uint32_t previous_state;		/* Previous state */
+
+	WT_UPDATE **update_list;		/* List of updates for abort */
 };
 
 /*
@@ -736,12 +843,14 @@ struct __wt_ref {
 	WT_PAGE * volatile home;	/* Reference page */
 	volatile uint32_t pindex_hint;	/* Reference page index hint */
 
-#define	WT_REF_DISK	0		/* Page is on disk */
-#define	WT_REF_DELETED	1		/* Page is on disk, but deleted */
-#define	WT_REF_LOCKED	2		/* Page locked for exclusive access */
-#define	WT_REF_MEM	3		/* Page is in cache and valid */
-#define	WT_REF_READING	4		/* Page being read */
-#define	WT_REF_SPLIT	5		/* Parent page split (WT_REF dead) */
+#define	WT_REF_DISK	 0		/* Page is on disk */
+#define	WT_REF_DELETED	 1		/* Page is on disk, but deleted */
+#define	WT_REF_LIMBO	 2		/* Page is in cache without history */
+#define	WT_REF_LOCKED	 3		/* Page locked for exclusive access */
+#define	WT_REF_LOOKASIDE 4		/* Page is on disk with lookaside */
+#define	WT_REF_MEM	 5		/* Page is in cache and valid */
+#define	WT_REF_READING	 6		/* Page being read */
+#define	WT_REF_SPLIT	 7		/* Parent page split (WT_REF dead) */
 	volatile uint32_t state;	/* Page state */
 
 	/*
@@ -763,13 +872,14 @@ struct __wt_ref {
 #undef	ref_ikey
 #define	ref_ikey	key.ikey
 
-	WT_PAGE_DELETED	*page_del;	/* Deleted on-disk page information */
+	WT_PAGE_DELETED	  *page_del;	/* Deleted page information */
+	WT_PAGE_LOOKASIDE *page_las;	/* Lookaside information */
 };
 /*
  * WT_REF_SIZE is the expected structure size -- we verify the build to ensure
  * the compiler hasn't inserted padding which would break the world.
  */
-#define	WT_REF_SIZE	48
+#define	WT_REF_SIZE	56
 
 /*
  * WT_ROW --
@@ -904,35 +1014,75 @@ struct __wt_ikey {
  * is done for an entry, WT_UPDATE structures are formed into a forward-linked
  * list.
  */
-WT_PACKED_STRUCT_BEGIN(__wt_update)
-	uint64_t txnid;			/* transaction */
+struct __wt_update {
+	volatile uint64_t txnid;	/* transaction ID */
+#if WT_TIMESTAMP_SIZE == 8
+	WT_DECL_TIMESTAMP(timestamp)	/* aligned uint64_t timestamp */
+#endif
 
 	WT_UPDATE *next;		/* forward-linked list */
 
 	uint32_t size;			/* data length */
 
-#define	WT_UPDATE_STANDARD	0
-#define	WT_UPDATE_DELETED	1
-#define	WT_UPDATE_RESERVED	2
+#define	WT_UPDATE_INVALID	0	/* diagnostic check */
+#define	WT_UPDATE_BIRTHMARK	1	/* transaction for on-page value */
+#define	WT_UPDATE_MODIFY	2	/* partial-update modify value */
+#define	WT_UPDATE_RESERVE	3	/* reserved */
+#define	WT_UPDATE_STANDARD	4	/* complete value */
+#define	WT_UPDATE_TOMBSTONE	5	/* deleted */
 	uint8_t type;			/* type (one byte to conserve memory) */
 
-	/* The untyped value immediately follows the WT_UPDATE structure. */
-#define	WT_UPDATE_DATA(upd)						\
-	((void *)((uint8_t *)(upd) + sizeof(WT_UPDATE)))
+	/* If the update includes a complete value. */
+#define	WT_UPDATE_DATA_VALUE(upd)					\
+	((upd)->type == WT_UPDATE_STANDARD ||				\
+	(upd)->type == WT_UPDATE_TOMBSTONE)
+
+#if WT_TIMESTAMP_SIZE != 8
+	WT_DECL_TIMESTAMP(timestamp)	/* unaligned uint8_t array timestamp */
+#endif
 
 	/*
-	 * The memory size of an update: include some padding because this is
-	 * such a common case that overhead of tiny allocations can swamp our
-	 * cache overhead calculation.
+	 * The update state is used for transaction prepare to manage
+	 * visibility and transitioning update structure state safely.
 	 */
-#define	WT_UPDATE_MEMSIZE(upd)						\
-	WT_ALIGN(sizeof(WT_UPDATE) + (upd)->size, 32)
-WT_PACKED_STRUCT_END
+	volatile uint8_t prepare_state;	/* Prepare state. */
+
+	/*
+	 * Zero or more bytes of value (the payload) immediately follows the
+	 * WT_UPDATE structure.  We use a C99 flexible array member which has
+	 * the semantics we want.
+	 */
+	uint8_t data[];			/* start of the data */
+};
+
 /*
- * WT_UPDATE_SIZE is the expected structure size -- we verify the build to
- * ensure the compiler hasn't inserted padding.
+ * WT_UPDATE_SIZE is the expected structure size excluding the payload data --
+ * we verify the build to ensure the compiler hasn't inserted padding.
  */
-#define	WT_UPDATE_SIZE	21
+#define	WT_UPDATE_SIZE	(22 + WT_TIMESTAMP_SIZE)
+
+/*
+ * The memory size of an update: include some padding because this is such a
+ * common case that overhead of tiny allocations can swamp our cache overhead
+ * calculation.
+ */
+#define	WT_UPDATE_MEMSIZE(upd)						\
+	WT_ALIGN(WT_UPDATE_SIZE + (upd)->size, 32)
+
+/*
+ * WT_MAX_MODIFY_UPDATE --
+ *	Limit update chains value to avoid penalizing reads and
+ *	permit truncation. Having a smaller value will penalize the cases
+ *	when history has to be maintained, resulting in multiplying cache
+ *	pressure.
+ */
+#define	WT_MAX_MODIFY_UPDATE	10
+
+/*
+ * WT_MODIFY_MEM_FACTOR	--
+ *	Limit update chains to a factor of the base document size.
+ */
+#define	WT_MODIFY_MEM_FACTOR	1
 
 /*
  * WT_INSERT --
