@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# Public Domain 2014-2017 MongoDB, Inc.
+# Public Domain 2014-2018 MongoDB, Inc.
 # Public Domain 2008-2014 WiredTiger, Inc.
 #
 # This is free and unencumbered software released into the public domain.
@@ -139,9 +139,9 @@ class TestSuiteConnection(object):
         self._conn = conn
         self._connlist = connlist
 
-    def close(self):
+    def close(self, config=''):
         self._connlist.remove(self._conn)
-        return self._conn.close()
+        return self._conn.close(config)
 
     # Proxy everything except what we explicitly define to the
     # wrapped connection
@@ -167,6 +167,10 @@ class WiredTigerTestCase(unittest.TestCase):
     # Can be a string or a callable function or lambda expression.
     conn_config = ''
 
+    # session_config can be overridden to add to basic session configuration.
+    # Can be a string or a callable function or lambda expression.
+    session_config = ''
+
     # conn_extensions can be overridden to add a list of extensions to load.
     # Each entry is a string (directory and extension name) and optional config.
     # Example:
@@ -319,17 +323,20 @@ class WiredTigerTestCase(unittest.TestCase):
         conn = wiredtiger.wiredtiger_open(home, config)
         return TestSuiteConnection(conn, self._connections)
 
-    # Can be overridden
+    # Can be overridden, but first consider setting self.session_config
     def setUpSessionOpen(self, conn):
-        return conn.open_session(None)
+        config = self.session_config
+        if hasattr(config, '__call__'):
+            config = self.session_config()
+        return conn.open_session(config)
 
     # Can be overridden
-    def close_conn(self):
+    def close_conn(self, config=''):
         """
         Close the connection if already open.
         """
         if self.conn != None:
-            self.conn.close()
+            self.conn.close(config)
             self.conn = None
 
     def open_conn(self, directory="."):
@@ -490,6 +497,45 @@ class WiredTigerTestCase(unittest.TestCase):
             with self.expectedStderr(message):
                 self.assertRaises(exceptionType, expr)
 
+    def assertRaisesException(self, exceptionType, expr,
+        exceptionString=None, optional=False):
+        """
+        Like TestCase.assertRaises(), with some additional options.
+        If the exceptionString argument is used, the exception's string
+        must match it. If optional is set, then no assertion occurs
+        if the exception doesn't occur.
+        Returns true if the assertion is raised.
+        """
+        raised = False
+        try:
+            expr()
+        except BaseException, err:
+            if not isinstance(err, exceptionType):
+                self.fail('Exception of incorrect type raised, got type: ' + \
+                    str(type(err)))
+            if exceptionString != None and exceptionString != str(err):
+                self.fail('Exception with incorrect string raised, got: "' + \
+                    str(err) + '"')
+            raised = True
+        if not raised and not optional:
+            self.fail('no assertion raised')
+        return raised
+
+    def raisesBusy(self, expr):
+        """
+        Execute the expression, returning true if a 'Resource busy'
+        exception is raised, returning false if no exception is raised.
+        Any other exception raises a test suite failure.
+        """
+        return self.assertRaisesException(wiredtiger.WiredTigerError, \
+            expr, exceptionString='Resource busy', optional=True)
+
+    def assertTimestampsEqual(self, ts1, ts2):
+        """
+        TestCase.assertEqual() for timestamps
+        """
+        self.assertEqual(int(ts1, 16), int(ts2, 16))
+
     def exceptionToStderr(self, expr):
         """
         Used by assertRaisesHavingMessage to convert an expression
